Index: lib/core/object.dart |
diff --git a/lib/core/object.dart b/lib/core/object.dart |
index ba41cb81840162b11f00a9e5fbd31f20c63a0c9f..4ab04bca8155661b38d34999f9f60204b549ceec 100644 |
--- a/lib/core/object.dart |
+++ b/lib/core/object.dart |
@@ -48,14 +48,15 @@ class Object { |
/** |
* [noSuchMethod] is invoked when users invoke a non-existant method |
* on an object. The name of the method and the arguments of the |
* invocation are passed to [noSuchMethod]. If [noSuchMethod] |
* returns a value, that value becomes the result of the original |
* invocation. |
* |
* The default behavior of [noSuchMethod] is to throw a |
* [noSuchMethodError]. |
*/ |
- external Dynamic noSuchMethod(String name, List args); |
+ external dynamic noSuchMethod(InvocationMirror invocation); |
+ |
/** |
* A representation of the runtime type of the object. |
*/ |
@@ -48,14 +48,15 @@ class Object { |
* [noSuchMethod] is invoked when users invoke a non-existant method |
* on an object. The name of the method and the arguments of the |
- * invocation are passed to [noSuchMethod]. If [noSuchMethod] |
- * returns a value, that value becomes the result of the original |
- * invocation. |
+ * invocation are passed to [noSuchMethod] in an [InvocationMirror]. |
+ * If [noSuchMethod] returns a value, that value becomes the result of |
+ * the original invocation. |
* |
* The default behavior of [noSuchMethod] is to throw a |